<?php
/**
 * @var $block \PortalPeople\ShippingFields\Block\Adminhtml\Order\ShippingFields
 */
?>
<div class="admin__page-section-item order-shipping-fields">
    <div class="admin__page-section-item-title">
        <span class="title"><?= __('Shipping Fields') ?></span>
    </div>
    <div class="admin__page-section-item-content">
        <div class="shipping-field-row">
            <strong><?= __('Preferred Shipping Date:') ?></strong>
            <span><?= $block->getShippingDate() ? $block->escapeHtml($block->getShippingDate()) : __('Not specified') ?></span>
        </div>
        
        <div class="shipping-field-row">
            <strong><?= __('Shipping Message:') ?></strong>
            <span><?= $block->getShippingMessage() ? $block->escapeHtml($block->getShippingMessage()) : __('Not specified') ?></span>
        </div>
    </div>
</div>
