<?php
/**
 * PortalPeople ShippingFields Module Registration
 */

use Magento\Framework\Component\ComponentRegistrar;

ComponentRegistrar::register(
    ComponentRegistrar::MODULE,
    'PortalPeople_ShippingFields',
    __DIR__
);
